import { Struct } from "./modules/api/struct/struct";
import { Project } from "./modules/api/project/project";
import { Sort } from "./modules/types/sort";
import { Authorization } from "./modules/api/authorization/authorization";
import { Company } from "./modules/api/company/company";
import { Common } from "./modules/api/struct/common/common";
import { Custom } from "./modules/api/struct/custom/custom";
import { Flow } from "./modules/api/flow/flow";
import { PreviousStep } from "./modules/api/step/previous-step";
import { Step } from "./modules/api/step/step";
import { NextStep } from "./modules/api/step/next-step";
export declare class ApipassSDK {
    static token: string;
    private static tokenService;
    private static companyService;
    private static authorizationService;
    private static projectService;
    private static commonService;
    private static customService;
    private static structService;
    private static flowService;
    /**
     * Init ApipassSDK.
     * @method
     * @param {string} jwtToken - Your JWTToken to authenticate in APIPASS.
     * @throws InvalidTokenException - if jwtToken is not present or is invalid.
     */
    static init(jwtToken: string): Promise<void>;
    /**
     * Find your company.
     * @async
     * @method
     * @returns company - returns promise with your company
     */
    static findCompany(): Promise<Company | undefined>;
    static findAllAuthorizations(): Promise<Array<Authorization> | undefined>;
    static findAuthorization(id: string): Promise<Authorization | undefined>;
    static deleteAuthorization(authorization: Authorization): Promise<void>;
    static saveAuthorization(authorization: Authorization): Promise<string | undefined>;
    static findAllProjects(sort?: Sort): Promise<Array<Project> | undefined>;
    static findProject(id: string): Promise<Project | undefined>;
    static findAllStructs(): Promise<Array<Struct> | undefined>;
    static findStruct(id: string): Promise<Struct | undefined>;
    static findStructFileContentById(id: string): Promise<any | undefined>;
    static findAllFlows(sort?: Sort, projectionExpression?: string): Promise<Array<Flow> | undefined>;
    static findFlow(id: string): Promise<Flow | undefined>;
    static saveFlow(flow: Flow): Promise<string | undefined>;
}
declare const _default: {
    ApipassSDK: typeof ApipassSDK;
    Authorization: typeof Authorization;
    Company: typeof Company;
    Project: typeof Project;
    Struct: typeof Struct;
    Common: typeof Common;
    Custom: typeof Custom;
    Flow: typeof Flow;
    Step: typeof Step;
    NextStep: typeof NextStep;
    PreviousStep: typeof PreviousStep;
    Sort: typeof Sort;
};
export default _default;
//# sourceMappingURL=apipass-api-js-sdk.d.ts.map